@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11929 2020-02-17 04:57:08Z Trista $
+# $Id: cms_plugins.py 11946 2020-02-22 13:22:03Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,35 +12,22 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-02-17 13:57:08 +0900 (週一, 17 二月 2020) $
-# $Revision: 11929 $
+# $Date: 2020-02-22 21:22:03 +0800 (週六, 22 二月 2020) $
+# $Revision: 11946 $
 
 import datetime
 
 from collections import OrderedDict
-
-from djangocms_forms.cms_plugins import FormFieldInline
-from djangocms_file.cms_plugins import FilePlugin
-from djangocms_file.models import File
-from djangocms_forms.cms_plugins import FormPlugin
-from djangocms_forms.forms import FormBuilder
-
-from django.contrib import admin
-from django.utils.translation import ugettext as _
-from django.conf import settings
-from django.template.loader import select_template
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
+from django.utils.translation import ugettext as _
+from django.template.loader import select_template
 from django.db.models import Q
 from aldryn_newsblog.models import Article, Category
 from taggit.models import Tag
 
 from Zephyrus.blog_extension import settings as _settings
-from Zephyrus.blog_extension.models import FilterPlugin, DatePluginConfig, Action
-
-
-
-
+from Zephyrus.blog_extension.models import FilterPlugin, DatePluginConfig
 
 class FilterArticlePlugin(CMSPluginBase):
     model = FilterPlugin
@@ -187,39 +174,5 @@ class DatePlugin(CMSPluginBase):
         })
         return context
 
-class ActionPlugin(FormPlugin):
-    model = Action
-    module = _("Action")
-    name = _("Call action Plugin")
-
-    def get_fieldsets(self, request, obj=None):
-        fieldsets = super(FormPlugin, self).get_fieldsets(
-            request, obj=None
-        )
-        return fieldsets
-
-    def render(self, context, instance, placeholder):
-        context = super(FormPlugin, self).render(context, instance, placeholder)
-        request = context['request']
-
-        form = FormBuilder(
-            initial={'referrer': request.path_info}, form_definition=instance,
-            label_suffix='', auto_id='%s')
-
-        redirect_delay = instance.redirect_delay or \
-            getattr(settings, 'DJANGOCMS_FORMS_REDIRECT_DELAY', 1000)
-
-        context.update({
-            'form': form,
-            'recaptcha_site_key': settings.DJANGOCMS_FORMS_RECAPTCHA_PUBLIC_KEY,
-            'redirect_delay': redirect_delay,
-            'fileId': instance.file.id,
-        })
-
-        return context
-
-
-
-plugin_pool.register_plugin(ActionPlugin)
 plugin_pool.register_plugin(FilterArticlePlugin)
 plugin_pool.register_plugin(DatePlugin)
\ No newline at end of file
