@@ -18,6 +18,7 @@
 from django.conf.urls import url
 from django.utils.http import urlquote  as django_urlquote
 from django.views.generic.detail import DetailView
+from django.utils.translation import ugettext_lazy as _
 from django.http import (
     HttpResponseRedirect,
     HttpResponsePermanentRedirect,
@@ -93,6 +94,34 @@ def get_queryset(self):
 
 CategoryArticleList.get_queryset = get_queryset
 
+class NoCategoryArticleList(CategoryArticleList):
+    def get_queryset(self):
+        return super(CategoryArticleList, self).get_queryset().filter(
+            categories=None
+        )
+    
+    def get(self, request):
+        return super(CategoryArticleList, self).get(request)
+
+    def get_context_data(self, **kwargs):
+        kwargs['newsblog_category'] = _("No category")
+        ctx = super(CategoryArticleList, self).get_context_data(**kwargs)
+        ctx['newsblog_category'] = _("No category")
+        return ctx
+
+class NoTagArticleList(TagArticleList):
+    def get_queryset(self):
+        return super(TagArticleList, self).get_queryset().filter(
+            tags=None
+        )
+
+    def get(self, request):
+        return super(TagArticleList, self).get(request)
+
+    def get_context_data(self, **kwargs):
+        kwargs['newsblog_tag'] = _("No tag")
+        return super(TagArticleList, self).get_context_data(**kwargs)
+
 from aldryn_newsblog.urls import urlpatterns
 from aldryn_newsblog.feeds import TagFeed, CategoryFeed
 
@@ -115,4 +144,14 @@ urlpatterns += [
         TagArticleList.as_view(), name='article-list-by-tag'),
     url(r'^tag/(?P<tag>.*)/feed/$',
         TagFeed(), name='article-list-by-tag-feed'),
-]
\ No newline at end of file
+]
+
+urlpatterns.insert(0, 
+    url(r'^category/no_category/$',
+        NoCategoryArticleList.as_view(), name='article-list-by-no-category')
+)
+
+urlpatterns.insert(0, 
+    url(r'^tag/no_tag/$',
+        NoTagArticleList.as_view(), name='article-list-by-no-tag')
+)
\ No newline at end of file
